@@ -13,7 +13,8 @@ as.yearmon.yearqtr <- function(x, frac = 0, ...) {
 as.yearmon.dates <- 
 as.yearmon.Date <- 
 as.yearmon.POSIXt <- function(x, ...) as.yearmon(with(as.POSIXlt(x, tz="GMT"), 1900 + year + mon/12))
-# as.jul.yearmon <- function(x, ...) jul(as.Date(x, ...)) # jul is from fame pkg
+# as.jul.yearmon <- function(x, ...) jul(as.Date(x, ...)) # jul is from tis pkg
+as.yearmon.mondate <-
 as.yearmon.timeDate <-
 as.yearmon.jul <- function(x, ...) as.yearmon(as.Date(x, ...))
 as.yearmon.factor <- function(x, ...) as.yearmon(as.character(x), ...)
@@ -32,7 +33,7 @@ as.yearmon.character <- function(x, format = "", ...) {
    z <- ifelse(has.short.keys & has.no.others,
       as.Date( paste("01", x, sep = "-"), paste("%d", format, sep = "-"), ... ),
       as.Date(x, format, ...))
-   as.yearmon(as.Date(z))
+   as.yearmon(as.Date(z, origin = "1970-01-01"))
 }
 as.yearmon.ti <- function(x, ...) as.yearmon(as.Date(x), ...)
 
@@ -41,8 +42,10 @@ as.yearmon.ti <- function(x, ...) as.yearmon(as.Date(x), ...)
 as.Date.yearmon <- function(x, frac = 0, ...) {
      x <- unclass(x)
      year <- floor(x + .001)
+	 ix <- !is.na(year)
      month <- floor(12 * (x - year) + 1 + .5 + .001)
-     dd.start <- as.Date(paste(year, month, 1, sep = "-")) 
+	 dd.start <- as.Date(rep(NA, length(year)))
+     dd.start[ix] <- as.Date(paste(year[ix], month[ix], 1, sep = "-")) 
      dd.end <- dd.start + 32 - as.numeric(format(dd.start + 32, "%d"))
      as.Date((1-frac) * as.numeric(dd.start) + frac * as.numeric(dd.end), origin = "1970-01-01")
 }
@@ -113,7 +116,7 @@ Ops.yearmon <- function(e1, e2) {
     e1 <- as.numeric(as.yearmon(e1))
     e2 <- as.numeric(as.yearmon(e2))
     rval <- NextMethod(.Generic)
-    if(is.numeric(rval)) rval <- as.yearmon(rval)
+    if(is.numeric(rval)) rval <- yearmon(rval)
     return(rval)
 }
 
@@ -127,7 +130,7 @@ Ops.yearmon <- function(e1, e2) {
         return(as.numeric(e1) - as.numeric(e2))
     if (!is.null(attr(e2, "class"))) 
       stop("can only subtract yearmon objects and numbers from yearmon objects")
-    structure(unclass(as.yearmon(e1)) - e2, class = "yearmon")
+    yearmon(unclass(e1) - e2)
 }
 
 is.numeric.yearmon <- function(x) FALSE
@@ -206,5 +209,6 @@ unique.yearmon <- function(x, incomparables = FALSE, ...) {
 	as.yearmon(unique.default(x, incomparables = incomparables, ...))
 }
 
+xtfrm.yearmon <- function(x) as.numeric(x)
 
 
